<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Entitlements;

/**
 * An entitlement event either grants or revokes an entitlement to a feature for a customer.
 *
 * @property string $id Unique identifier for the object.
 * @property string $object String representing the object's type. Objects of the same type share the same value.
 * @property string $customer The customer that is being granted or revoked entitlement to/from a feature.
 * @property string $feature The feature that the customer is being granted/revoked entitlement to/from.
 * @property null|\Stripe\StripeObject $grant Contains information about type=grant entitlement event.
 * @property bool $livemode Has the value <code>true</code> if the object exists in live mode or the value <code>false</code> if the object exists in test mode.
 * @property null|\Stripe\StripeObject $quantity Contains information about entitlement events relating to features with type=quantity. Required when the feature has type=quantity.
 * @property null|\Stripe\StripeObject $revoke Contains information about type=revoke entitlement event.
 * @property string $type Whether the event is a grant or revocation of the feature.
 */
class Event extends \Stripe\ApiResource {
	const OBJECT_NAME = 'entitlements.event';

	use \Stripe\ApiOperations\Create;

	const TYPE_GRANT = 'grant';

	const TYPE_REVOKE = 'revoke';
}
