<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe;

/**
 * @property string $id Unique identifier for the object.
 * @property string $object String representing the object's type. Objects of the same type share the same value.
 * @property int $created Time at which the object was created. Measured in seconds since the Unix epoch.
 * @property int $expires Time at which the key will expire. Measured in seconds since the Unix epoch.
 * @property bool $livemode Has the value <code>true</code> if the object exists in live mode or the value <code>false</code> if the object exists in test mode.
 * @property null|string $secret The key's secret. You can use this value to make authorized requests to the Stripe API.
 */
class EphemeralKey extends ApiResource {
	const OBJECT_NAME = 'ephemeral_key';

	use ApiOperations\Create {
		create as protected _create;
	}

	use ApiOperations\Delete;

	/**
	 * @param null|array $params
	 * @param null|array|string $opts
	 *
	 * @throws \Stripe\Exception\InvalidArgumentException if stripe_version is missing
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\EphemeralKey the created key
	 */
	public static function create($params = null, $opts = null) {
		if (! $opts || ! isset($opts['stripe_version'])) {
			throw new Exception\InvalidArgumentException('stripe_version must be specified to create an ephemeral key');
		}

		return self::_create($params, $opts);
	}
}
