<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service;

class ApplePayDomainService extends \Stripe\Service\AbstractService {
	/**
	 * List apple pay domains.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\ApplePayDomain>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/apple_pay/domains', $params, $opts);
	}

	/**
	 * Create an apple pay domain.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\ApplePayDomain
	 */
	public function create($params = null, $opts = null) {
		return $this->request('post', '/v1/apple_pay/domains', $params, $opts);
	}

	/**
	 * Delete an apple pay domain.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\ApplePayDomain
	 */
	public function delete($id, $params = null, $opts = null) {
		return $this->request('delete', $this->buildPath('/v1/apple_pay/domains/%s', $id), $params, $opts);
	}

	/**
	 * Retrieve an apple pay domain.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\ApplePayDomain
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/apple_pay/domains/%s', $id), $params, $opts);
	}
}
