<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\Apps;

class SecretService extends \Stripe\Service\AbstractService {
	/**
	 * List all secrets stored on the given scope.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\Apps\Secret>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/apps/secrets', $params, $opts);
	}

	/**
	 * Create or replace a secret in the secret store.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Apps\Secret
	 */
	public function create($params = null, $opts = null) {
		return $this->request('post', '/v1/apps/secrets', $params, $opts);
	}

	/**
	 * Deletes a secret from the secret store by name and scope.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Apps\Secret
	 */
	public function deleteWhere($params = null, $opts = null) {
		return $this->request('post', '/v1/apps/secrets/delete', $params, $opts);
	}

	/**
	 * Finds a secret in the secret store by name and scope.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Apps\Secret
	 */
	public function find($params = null, $opts = null) {
		return $this->request('get', '/v1/apps/secrets/find', $params, $opts);
	}
}
