<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\BillingPortal;

class ConfigurationService extends \Stripe\Service\AbstractService {
	/**
	 * Returns a list of configurations that describe the functionality of the customer
	 * portal.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\BillingPortal\Configuration>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/billing_portal/configurations', $params, $opts);
	}

	/**
	 * Creates a configuration that describes the functionality and behavior of a
	 * PortalSession.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\BillingPortal\Configuration
	 */
	public function create($params = null, $opts = null) {
		return $this->request('post', '/v1/billing_portal/configurations', $params, $opts);
	}

	/**
	 * Retrieves a configuration that describes the functionality of the customer
	 * portal.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\BillingPortal\Configuration
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/billing_portal/configurations/%s', $id), $params, $opts);
	}

	/**
	 * Updates a configuration that describes the functionality of the customer portal.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\BillingPortal\Configuration
	 */
	public function update($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/billing_portal/configurations/%s', $id), $params, $opts);
	}
}
