<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service;

class EphemeralKeyService extends \Stripe\Service\AbstractService {
	/**
	 * Invalidates a short-lived API key for a given resource.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\EphemeralKey
	 */
	public function delete($id, $params = null, $opts = null) {
		return $this->request('delete', $this->buildPath('/v1/ephemeral_keys/%s', $id), $params, $opts);
	}

	/**
	 * Creates a short-lived API key for a given resource.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\EphemeralKey
	 */
	public function create($params = null, $opts = null) {
		if (! $opts || ! isset($opts['stripe_version'])) {
			throw new \Stripe\Exception\InvalidArgumentException('stripe_version must be specified to create an ephemeral key');
		}

		return $this->request('post', '/v1/ephemeral_keys', $params, $opts);
	}
}
