<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\FinancialConnections;

class SessionService extends \Stripe\Service\AbstractService {
	/**
	 * To launch the Financial Connections authorization flow, create a
	 * <code>Session</code>. The session’s <code>client_secret</code> can be used to
	 * launch the flow using Stripe.js.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\FinancialConnections\Session
	 */
	public function create($params = null, $opts = null) {
		return $this->request('post', '/v1/financial_connections/sessions', $params, $opts);
	}

	/**
	 * Retrieves the details of a Financial Connections <code>Session</code>.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\FinancialConnections\Session
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/financial_connections/sessions/%s', $id), $params, $opts);
	}
}
