<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\Issuing;

/**
 * Service factory class for API resources in the Issuing namespace.
 *
 * @property AuthorizationService $authorizations
 * @property CardholderService $cardholders
 * @property CardService $cards
 * @property CreditUnderwritingRecordService $creditUnderwritingRecords
 * @property DisputeService $disputes
 * @property PersonalizationDesignService $personalizationDesigns
 * @property PhysicalBundleService $physicalBundles
 * @property TokenService $tokens
 * @property TransactionService $transactions
 */
class IssuingServiceFactory extends \Stripe\Service\AbstractServiceFactory {
	/**
	 * @var array<string, string>
	 */
	private static $classMap = [
		'authorizations'            => AuthorizationService::class,
		'cardholders'               => CardholderService::class,
		'cards'                     => CardService::class,
		'creditUnderwritingRecords' => CreditUnderwritingRecordService::class,
		'disputes'                  => DisputeService::class,
		'personalizationDesigns'    => PersonalizationDesignService::class,
		'physicalBundles'           => PhysicalBundleService::class,
		'tokens'                    => TokenService::class,
		'transactions'              => TransactionService::class,
	];

	protected function getServiceClass($name) {
		return \array_key_exists($name, self::$classMap) ? self::$classMap[$name] : null;
	}
}
