<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service;

class PlanService extends \Stripe\Service\AbstractService {
	/**
	 * Returns a list of your plans.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\Plan>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/plans', $params, $opts);
	}

	/**
	 * You can now model subscriptions more flexibly using the <a href="#prices">Prices
	 * API</a>. It replaces the Plans API and is backwards compatible to simplify your
	 * migration.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Plan
	 */
	public function create($params = null, $opts = null) {
		return $this->request('post', '/v1/plans', $params, $opts);
	}

	/**
	 * Deleting plans means new subscribers can’t be added. Existing subscribers aren’t
	 * affected.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Plan
	 */
	public function delete($id, $params = null, $opts = null) {
		return $this->request('delete', $this->buildPath('/v1/plans/%s', $id), $params, $opts);
	}

	/**
	 * Retrieves the plan with the given ID.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Plan
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/plans/%s', $id), $params, $opts);
	}

	/**
	 * Updates the specified plan by setting the values of the parameters passed. Any
	 * parameters not provided are left unchanged. By design, you cannot change a
	 * plan’s ID, amount, currency, or billing cycle.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Plan
	 */
	public function update($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/plans/%s', $id), $params, $opts);
	}
}
