<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service;

class PromotionCodeService extends \Stripe\Service\AbstractService {
	/**
	 * Returns a list of your promotion codes.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\PromotionCode>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/promotion_codes', $params, $opts);
	}

	/**
	 * A promotion code points to a coupon. You can optionally restrict the code to a
	 * specific customer, redemption limit, and expiration date.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\PromotionCode
	 */
	public function create($params = null, $opts = null) {
		return $this->request('post', '/v1/promotion_codes', $params, $opts);
	}

	/**
	 * Retrieves the promotion code with the given ID. In order to retrieve a promotion
	 * code by the customer-facing <code>code</code> use <a
	 * href="/docs/api/promotion_codes/list">list</a> with the desired
	 * <code>code</code>.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\PromotionCode
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/promotion_codes/%s', $id), $params, $opts);
	}

	/**
	 * Updates the specified promotion code by setting the values of the parameters
	 * passed. Most fields are, by design, not editable.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\PromotionCode
	 */
	public function update($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/promotion_codes/%s', $id), $params, $opts);
	}
}
