<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\Tax;

class SettingsService extends \Stripe\Service\AbstractService {
	/**
	 * Retrieves Tax <code>Settings</code> for a merchant.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Tax\Settings
	 */
	public function retrieve($params = null, $opts = null) {
		return $this->request('get', '/v1/tax/settings', $params, $opts);
	}

	/**
	 * Updates Tax <code>Settings</code> parameters used in tax calculations. All
	 * parameters are editable but none can be removed once set.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Tax\Settings
	 */
	public function update($params = null, $opts = null) {
		return $this->request('post', '/v1/tax/settings', $params, $opts);
	}
}
