<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\TestHelpers\Treasury;

class OutboundTransferService extends \Stripe\Service\AbstractService {
	/**
	 * Transitions a test mode created OutboundTransfer to the <code>failed</code>
	 * status. The OutboundTransfer must already be in the <code>processing</code>
	 * state.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Treasury\OutboundTransfer
	 */
	public function fail($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/test_helpers/treasury/outbound_transfers/%s/fail', $id), $params, $opts);
	}

	/**
	 * Transitions a test mode created OutboundTransfer to the <code>posted</code>
	 * status. The OutboundTransfer must already be in the <code>processing</code>
	 * state.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Treasury\OutboundTransfer
	 */
	public function post($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/test_helpers/treasury/outbound_transfers/%s/post', $id), $params, $opts);
	}

	/**
	 * Transitions a test mode created OutboundTransfer to the <code>returned</code>
	 * status. The OutboundTransfer must already be in the <code>processing</code>
	 * state.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Treasury\OutboundTransfer
	 */
	public function returnOutboundTransfer($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/test_helpers/treasury/outbound_transfers/%s/return', $id), $params, $opts);
	}
}
