<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\Treasury;

class CreditReversalService extends \Stripe\Service\AbstractService {
	/**
	 * Returns a list of CreditReversals.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\Treasury\CreditReversal>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/treasury/credit_reversals', $params, $opts);
	}

	/**
	 * Reverses a ReceivedCredit and creates a CreditReversal object.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Treasury\CreditReversal
	 */
	public function create($params = null, $opts = null) {
		return $this->request('post', '/v1/treasury/credit_reversals', $params, $opts);
	}

	/**
	 * Retrieves the details of an existing CreditReversal by passing the unique
	 * CreditReversal ID from either the CreditReversal creation request or
	 * CreditReversal list.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Treasury\CreditReversal
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/treasury/credit_reversals/%s', $id), $params, $opts);
	}
}
