<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\Treasury;

/**
 * Service factory class for API resources in the Treasury namespace.
 *
 * @property CreditReversalService $creditReversals
 * @property DebitReversalService $debitReversals
 * @property FinancialAccountService $financialAccounts
 * @property InboundTransferService $inboundTransfers
 * @property OutboundPaymentService $outboundPayments
 * @property OutboundTransferService $outboundTransfers
 * @property ReceivedCreditService $receivedCredits
 * @property ReceivedDebitService $receivedDebits
 * @property TransactionEntryService $transactionEntries
 * @property TransactionService $transactions
 */
class TreasuryServiceFactory extends \Stripe\Service\AbstractServiceFactory {
	/**
	 * @var array<string, string>
	 */
	private static $classMap = [
		'creditReversals'    => CreditReversalService::class,
		'debitReversals'     => DebitReversalService::class,
		'financialAccounts'  => FinancialAccountService::class,
		'inboundTransfers'   => InboundTransferService::class,
		'outboundPayments'   => OutboundPaymentService::class,
		'outboundTransfers'  => OutboundTransferService::class,
		'receivedCredits'    => ReceivedCreditService::class,
		'receivedDebits'     => ReceivedDebitService::class,
		'transactionEntries' => TransactionEntryService::class,
		'transactions'       => TransactionService::class,
	];

	protected function getServiceClass($name) {
		return \array_key_exists($name, self::$classMap) ? self::$classMap[$name] : null;
	}
}
